/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useContext, useState, useEffect } from 'react';
import { Grid } from '@material-ui/core';
import Rating from '@material-ui/lab/Rating';
import IconButton from '@material-ui/core/IconButton';
import StarBorderIcon from '@material-ui/icons/StarBorder';
import FavoriteIcon from '@material-ui/icons/Favorite';
import InfoIcon from '@material-ui/icons/Info';
import { Store } from '../Store.js'
import ReportModal from './ReportModal.js';
import SignUpModal from './SignUpModal.js';
import LoginModal from './LoginModal.js';
import { putRequest, getRequest } from './HelperFunctions/getAxiosConfig.js'

export default function CollectionReview(props) {
	const [likes, setLikes] = useState(0);
	const [liked, setLiked] = useState(false);
	const [stars, setStars] = useState(0);
	const [reportOpen, setReportOpen] = useState(false);
	const [sign_up_open, setSignUpOpen] = useState(false);
	const [log_in_open, setLoginOpen] = useState(false);
	const { state } = useContext(Store);

	function handleSuccessfulGet(data) {
		setLikes(Number(data.likes_count));
		setLiked(data.liked);
	}

	useEffect(() => {
		const url = `/collections/${props.id}`

		getRequest(url, handleSuccessfulGet, (error) => { console.log(error) })

	}, [props.id, state.currentUser.id]);

	const handleClickReport = () => {
		setReportOpen(true);
	}

	function handleSuccess(data) {
		setLiked(!liked)
		setLikes(data.count)
	}

	const handleLikeClick = () => {
		if (state.currentUser.id) {
			const url = `/collections/${props.id}/like`
			putRequest(url, {}, handleSuccess, (error) => { console.log(error) })
		} else
			setSignUpOpen(true);
	}

	const handleSetStars = (value) => {
		setStars(value);
		props.scrollToComment();
	}

	const handleCloseModal = () => {
		setReportOpen(false);
	}

	return (
		<Grid container direction="column">
			<Grid sm={12} container direction="row" alignItems="center">
				<Grid item>
					<Rating
						name="customized-empty"
						value={stars}
						onChange={(e, value) => handleSetStars(value)}
						precision={0.5}
						style={{ color: "#666" }}
						emptyIcon={<StarBorderIcon fontSize="inherit" />}
					/>
				</Grid>
				<Grid item justify="center" alignItems="center">
					<IconButton aria-label="like" onClick={handleLikeClick}>
						{likes}<FavoriteIcon style={{ fill: liked ? "red" : null }} />
					</IconButton>
				</Grid>
			</Grid>
			<Grid item sm={12}>
				<IconButton
					aria-label="report"
					style={{ fontSize: 'small' }}
					onClick={handleClickReport}>
					<InfoIcon />Reportar erro ou abuso
				</IconButton>
				<ReportModal
					open={reportOpen}
					handleClose={handleCloseModal}
					form="colecao"
					complainableId={props.id}
					complainableType="Collection"
				/>
			</Grid>
			<SignUpModal
				open={sign_up_open}
				handleClose={() => setSignUpOpen(false)}
				openLogin={() => setLoginOpen(true)}
			/>
			<LoginModal
				open={log_in_open}
				handleClose={() => setLoginOpen(false)}
			/>
		</Grid>
	);
}
