/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import { HeaderGrid, ContainerStyled, Carregados } from '../StyledComponents.js'
import Grid from '@material-ui/core/Grid';
import ResourceCardFunction from '../../ResourceCardFunction.js'
import { ButtonMostrarMaisRecurso } from '../PanelComponents/ButtonsArea'
import { getRequest } from '../../HelperFunctions/getAxiosConfig'
import { StyledGrid } from '../StyledComponents'
 
export default function TabRecursos(props) {
    const [arr, setArr] = useState([])
    const [objsSlice, setSlice] = useState([])
    const handleSlice = (newArr) => { setSlice(newArr) }

    useEffect(() => {
        setArr(props.learningObjs)
        setSlice(props.learningObjs.slice(0, 4))
    }, [])

    function handleSuccess(data) {
        setArr(data)
        setSlice(data)
    }
    const showMore = (quantity) => {
        var sliceLength = objsSlice.length
        var newLength = sliceLength + quantity

        if (newLength > 12) {
            const url = `/users/${props.id}/learning_objects?limit=${newLength}$offset=4`
            getRequest(url, handleSuccess, (error) => { console.log(error) })
        }
        else {
            handleSlice(arr.slice(0, sliceLength + quantity))
        }

    }

    return (
        <ContainerStyled style={{ flexDirection: "column" }}>

            <HeaderGrid container>
                <Grid item xs={12}>
                    <h3>Recursos Publicados <b style={{ fontWeight: "500" }}>({props.count})</b></h3>
                </Grid>
            </HeaderGrid>

            <StyledGrid container spacing={1} style={{ paddingLeft: "30px", paddingRight: "15px" }}>
                {
                    objsSlice.map((card) =>
                        <Grid item xs={12} sm={6} md={'auto'} lg={3} key={card.id}>
                            <ResourceCardFunction
                                avatar={card.publisher.avatar}
                                id={card.id}
                                thumbnail={card.thumbnail}
                                type={card.object_type ? card.object_type : "Outros"}
                                title={card.name}
                                published={card.state === "published" ? true : false}
                                likeCount={card.likes_count}
                                liked={card.liked}
                                rating={card.review_average}
                                author={card.publisher.name}
                                tags={card.tags}
                                href={"/recurso/" + card.id}
                                downloadableLink={card.default_attachment_location}
                            />
                        </Grid>
                    )
                }
            </StyledGrid>

            <Carregados>
                <p style={{ margin: "0 0 10px", fontSize: "14px" }}>
                    Carregados {objsSlice.length} de {arr.length}
                </p>

                {
                    props.count > 5 &&
                    <React.Fragment>
                        <ButtonMostrarMaisRecurso onClick={() => { showMore(4) }}>
                            <span style={{ color: "#fff", fontSize: "14px", fontWeight: "500" }}>MOSTRAR MAIS 4</span>
                        </ButtonMostrarMaisRecurso>

                        <ButtonMostrarMaisRecurso onClick={() => { showMore(20) }}>
                            <span style={{ color: "#fff", fontSize: "14px", fontWeight: "500" }}>MOSTRAR MAIS 20</span>
                        </ButtonMostrarMaisRecurso>
                    </React.Fragment>
                }

            </Carregados>

        </ContainerStyled>
    )
}
