/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import styled from 'styled-components'
import Paper from '@material-ui/core/Paper';
import Button from '@material-ui/core/Button';
import { apiDomain } from '../../../env';
import Bolo from '../../../img/Bolo.png'
import LoadingSpinner from '../../LoadingSpinner.js'
import ActivityListItem from '../../ActivityListItem.js'
import List from '@material-ui/core/List';
import { getRequest } from '../../HelperFunctions/getAxiosConfig.js'
import Grid from '@material-ui/core/Grid';
import DefaultProfile from '../../../img/default_profile.png';
import SnackBar from '../../SnackbarComponent'


export default function TabPanelAtividades(props) {

    const [loading, handleLoading] = useState(true)
    const [loadingMore, handleLoadingMore] = useState(false);
    const [notifications, setNotifications] = useState([]);
    const [notificatonsLength, setLength] = useState(0);
    const [totalResults, setTotalResults] = useState(0);
    const [limit, setLimit] = useState(30);
    const [error, setError] = useState(false)
    const [snackInfo, setSnackInfo] = useState({
        open: false,
        text: '',
        severity: '',
        color: '',
    })

    function handleCloseSnackBar() {
        const info = {
            open: false,
            text: '',
            severity: '',
            color: '',
        }
        handleSnackInfo(info)
    }

    function handleSnackInfo(info) {
        setSnackInfo({
            ...info
        })
    }

    const showMore = (offset) => {
        handleLoadingMore(true);
        const url = `/feed?offset=${limit}&limit=${offset}`
        setLimit(limit + offset)
        getRequest(url, handleSuccess, handleError)
    }

    function handleError(error) {
        const info = {
            open: true,
            text: 'Ocorreu um erro ao tentar carregar suas notificações!',
            severity: 'error',
            color: 'red',
        }
        handleSnackInfo(info)
        handleLoadingMore(false)
        handleLoading(false)
        setError(true)
    }

    function handleSuccess(data, header) {
        if (header.has('X-Total-Count')) {
            setTotalResults(header.get('X-Total-Count'));
        }
        if (data.errors) {
            const info = {
                open: true,
                text: 'Ocorreu um erro ao tentar carregar suas notificações!',
                severity: 'error',
                color: 'red',
            }
            handleSnackInfo(info)
            handleLoadingMore(false)
            handleLoading(false)
            setError(true)
        }
        else {
            if (data.length >= 1) {
                handleLoadingMore(false)
                let currData = [...notifications]
                currData = currData.concat(data)
                setNotifications(currData)
                setLength(currData.length)
                handleLoading(false)
            }
            else {
                const info = {
                    open: true,
                    text: 'Não há mais notificações para serem carregadas...',
                    severity: 'warning',
                    color: '#FFC125'
                }
                handleSnackInfo(info)
                handleLoadingMore(false)
                handleLoading(false)
            }
        }
    }
    useEffect(() => {
        const url = `/feed?offset=0&limit=30`

        getRequest(url, handleSuccess, handleError)
    }, [])

    return (
        <MainContainerDesktop>
            <SnackBar
                snackbarOpen={snackInfo.open}
                handleClose={handleCloseSnackBar}
                severity={snackInfo.severity}
                color={snackInfo.color}
                text={snackInfo.text}
            />
            <Paper elevation={3}>
                <div>
                    <DivTitulo>
                        <InnerDivTitulo>
                            <TituloContent>
                                <p style={{ margin: "0 0 10px", marginBottom: "40px" }}>Todas Notificações</p>
                            </TituloContent>
                        </InnerDivTitulo>
                    </DivTitulo>
                    {
                        loading ?
                            (
                                <LoadingSpinner text={'Carregando Atividades'} />
                            )
                            :
                            (
                                [
                                    <div>
                                        {
                                            error ?
                                                <p
                                                    style={{ fontSize: "15px", fontWeight: "lighter", margin: "0 0 10px", display: "flex", justifyContent: "center", textAlign: "center" }}
                                                >
                                                    Erro ao tentar obter as notificações
                                                </p>
                                                :
                                                notificatonsLength === 0 ?
                                                    (

                                                        <NoNotificationsDiv>
                                                            <div>
                                                                <div>
                                                                    <H3Styled><img src={Bolo} alt='bolo' style={{ width: "23px" }} />  Você se cadastrou na Plataforma</H3Styled>
                                                                </div>
                                                                <p
                                                                    style={{ fontSize: "15px", fontWeight: "lighter", margin: "0 0 10px", display: "flex", justifyContent: "center", textAlign: "center" }}
                                                                >Construa conosco a plataforma e amplie sua rede de conhecimento interagindo
                                                            <br />
                                                            com pessoas envolvidas com experiências que ocorrem em todo o Brasil!
                                                            </p>
                                                            </div>
                                                        </NoNotificationsDiv>

                                                    )
                                                    :
                                                    (
                                                        <>
                                                            <List height={400} width={300}>
                                                                {
                                                                    notifications.map((notification, id) =>
                                                                        <ActivityListItem
                                                                            key={id}
                                                                            onMenuBar={false}
                                                                            avatar={notification.owner.avatar ? apiDomain + notification.owner.avatar : DefaultProfile}
                                                                            activity={notification.activity}
                                                                            actionType={notification.trackable_type}
                                                                            objectType={notification.recipient_type}
                                                                            createdAt={notification.created_at}
                                                                            ownerName={notification.owner.name}
                                                                            ownerHref={'/usuario-publico/' + notification.owner.id}
                                                                            recipientName={notification.recipient.name}
                                                                            recipientHref={"/recurso/" + notification.recipient.id}
                                                                        />
                                                                    )
                                                                }
                                                            </List>
                                                            {
                                                                loadingMore ?
                                                                    <LoadingSpinner text="Carregando mais atividades..." />
                                                                    :
                                                                    <Grid container direction="row" alignItems="center" justify="flex-start">
                                                                        <Grid item xs={12} md={4}>
                                                                            <LoadMoreButton onClick={() => { showMore(4) }}>CARREGAR MAIS 4</LoadMoreButton>
                                                                        </Grid>
                                                                        <Grid item xs={12} md={4}>
                                                                            <LoadMoreButton onClick={() => { showMore(20) }}>CARREGAR MAIS 20</LoadMoreButton>
                                                                        </Grid>
                                                                        <Grid xs={12} md={4} item style={{ fontSize: "14px", color: "#666" }}>
                                                                            <ShowData disabled={true}>
                                                                                Mostrando {notificatonsLength} {notificatonsLength === 1 ? "Atividade " : "Atividades "}
                                                                            de {totalResults}
                                                                            </ShowData>
                                                                        </Grid>
                                                                    </Grid>
                                                            }
                                                        </>
                                                    )
                                        }
                                    </div>

                                ]
                            )
                    }
                </div>
            </Paper>
        </MainContainerDesktop>
    )
}

const MainContainerDesktop = styled.div`
    padding : 10px 0 8px 0;
    margin-left : auto;
    margin-right : auto;

    @media screen and (min-width: 1200px) {
        width : 1170px;
    }
    @media screen and (min-width: 992px) and (max-width : 1199px){
        width : 970px;
    }
    @media screen and (min-width: 768px) and (max-width : 991px) {
        width : 750px;
    }
`

const H3Styled = styled.h3`
    font-size: 24px;
    font-weight : lighter;
    color : #00bcd4;
    margin-top : 20px;
    margin-bottom : 10px;
    display : flex;
    justify-content : center;
    align-items : center;
`

const NoNotificationsDiv = styled.div`
    height : 250px;
    display: flex;
    align-items : center;
    justify-content : center;
`

const LoadMoreButton = styled(Button)`
    outline : none !important;
    display : block !important;
    cusor : pointer !important;
    min-height : 36px !important;
    min-widht : 88px !important;
    line-height: 36px !important;
    vertical-align: middle !important;
    border : 0 !important;
    padding : 0 px !important;
    margin : auto !important;
    text-decoration : none !important;
    font-weight : 500 !important;
    overflow : hidden !important;
    text-transform : uppercase !important;
    font-size : 14px !important;
    background : transparent !important;
    color : #666 !important
    &:hover {
        background : rgba(158,158,158,0.2) !important
    }
`

const ShowData = styled(Button)`
    outline : none !important;
    display : block !important;
    cusor : pointer !important;
    min-height : 36px !important;
    min-widht : 88px !important;
    line-height: 36px !important;
    vertical-align: middle !important;
    border : 0 !important;
    padding : 0 px !important;
    margin : auto !important;
    text-decoration : none !important;
    font-weight : 500 !important;
    overflow : hidden !important;
    text-transform : none !important;
    font-size : 14px !important;
    background : transparent !important;
    color : #666 !important
    &:hover {
        background : rgba(158,158,158,0.2) !important
    }
`

const TituloContent = styled.div`
    display : block;
    z-index : 1;
    position : relative;
    font-family: Roboto, sans-serif;
    font-weight : ligther;
`

const InnerDivTitulo = styled.div`
    margin-top : 24px;
    padding-top : 16px;
    padding-left : 16px;
    padding-right : 16px;
    font-size: 30px;
    font-weight: lighter;
    color:  #6e6e6e;
    text-align: center;
`


const DivTitulo = styled.div`
    display : flex;
    justify-content : center;
    font-size: 14px;
    font-weight: 500;
    letter-spacing: .01em;
    line-height: 1.2em;
    margin : 0;
    border-bottom: 1px solid #eee;
`
